@@ -356,10 +356,8 @@ class WizataDSAPIClient:
                 if "models" in obj.keys():
                     for mlmodel in obj["models"]:
                         execution.models.append(self.get(MLModel(model_id=mlmodel["id"])))
-                if "anomaliesList" in obj.keys():
-                    execution.anomalies = obj["anomaliesList"]
-                if "dataframe" in obj.keys():
-                    execution.output_ds_dataframe = self.get(DSDataFrame(df_id=obj["dataframe"]["id"]))
+                if "resultDataframe" in obj.keys():
+                    execution.output_ds_dataframe = self.get(DSDataFrame(df_id=obj["resultDataframe"]["id"]))
                 return execution
             else:
                 raise self.__raise_error(response)
